/*
 * Copyright (c) 2012 Devscripts developers
 *
 * "THE BEER-WARE LICENSE" (Revision 42):
 * Benjamin Drung wrote this file. As long as you retain this notice you
 * can do whatever you want with this stuff. If we meet some day, and you think
 * this stuff is worth it, you can buy me a beer in return.
 */
