@ Copyright (C) 2012 Devscripts developers
@
@ This library is free software; you can redistribute it and/or
@ modify it under the terms of the GNU Library General Public
@ License as published by the Free Software Foundation;
@ version 2 of the License.
@
@ This library is distributed in the hope that it will be useful,
@ but WITHOUT ANY WARRANTY; without even the implied warranty of
@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
@ Library General Public License for more details.
